@@ -1,8 +1,10 @@
 #ifndef DBALLE_DB_H
 #define DBALLE_DB_H
 
+#include <dballe/transaction.h>
 #include <dballe/core/defs.h>
 #include <dballe/db/defs.h>
+#include <dballe/sql/fwd.h>
 #include <wreport/varinfo.h>
 #include <wreport/var.h>
 #include <vector>
@@ -27,13 +29,10 @@ struct Messages;
 struct DB;
 
 namespace db {
-struct Connection;
-struct ODBCConnection;
 
-/**
- * Simple typedef to make typing easier
- */
-typedef std::vector<wreport::Varcode> AttrList;
+/// Format a db::Format value to a string
+std::string format_format(Format format);
+
 
 /// Common interface for all kinds of cursors
 struct Cursor
@@ -152,31 +151,6 @@ struct CursorSummary : public Cursor
     virtual size_t get_count() const = 0;
 };
 
-
-#if 0
-    /**
-     * Query attributes for the current variable
-     */
-    virtual void query_attrs(std::function<void(std::unique_ptr<wreport::Var>&&)> dest) = 0;
-
-    /**
-     * Insert/overwrite new attributes for the current variable
-     *
-     * @param attrs
-     *   The attributes to be added
-     */
-    virtual void attr_insert(const Values& attrs) = 0;
-
-    /**
-     * Delete attributes for the current variable
-     *
-     * @param qcs
-     *   Array of WMO codes of the attributes to delete.  If empty, all attributes
-     *   associated to id_data will be deleted.
-     */
-    virtual void attr_remove(const AttrList& qcs) = 0;
-#endif
-
 }
 
 class DB
@@ -187,21 +161,6 @@ public:
     static db::Format get_default_format();
     static void set_default_format(db::Format format);
 
-    /**
-     * Start a session with DB-All.e
-     *
-     * @param dsn
-     *   The ODBC DSN of the database to use
-     * @param user
-     *   The user name to use to connect to the DSN
-     * @param password
-     *   The password to use to connect to the DSN.  To specify an empty password,
-     *   pass "" or NULL
-     * @return
-     *   The new DB object
-     */
-    static std::unique_ptr<DB> connect(const char* dsn, const char* user, const char* password);
-
     /**
      * Create from a SQLite file pathname
      *
@@ -211,11 +170,8 @@ public:
     static std::unique_ptr<DB> connect_from_file(const char* pathname);
 
     /**
-     * Create from an url-like specification, that can be:
-     * 
-     * @l sqlite:[//]foo.sqlite
-     * @l odbc://[user[:pass]@]dsn
-     * @l test:[//]
+     * Create from an url-like specification, as described in
+     * doc/fapi_connect.md
      *
      * @param url
      *   The url-like connection descriptor
@@ -238,7 +194,7 @@ public:
     /**
      * Create a database from an open Connection
      */
-    static std::unique_ptr<DB> create(std::unique_ptr<db::Connection> conn);
+    static std::unique_ptr<DB> create(std::unique_ptr<sql::Connection> conn);
 
     /**
      * Return TRUE if the string looks like a DB URL
@@ -299,6 +255,12 @@ public:
     virtual std::map<std::string, int> get_repinfo_priorities() = 0;
 
 public:
+    /**
+     * Begin a transaction on this database, and return a Transaction object
+     * that can be used to commit it.
+     */
+    virtual std::unique_ptr<dballe::Transaction> transaction() = 0;
+
     /**
      * Insert station values into the database
      *
@@ -315,7 +277,27 @@ public:
      *   data for a station that does not yet exists in the database, it will
      *   be created.
      */
-    virtual void insert_station_data(StationValues& vals, bool can_replace, bool station_can_add) = 0;
+    void insert_station_data(StationValues& vals, bool can_replace, bool station_can_add);
+
+    /**
+     * Insert station values into the database
+     *
+     * The IDs of the station andl all variables that were inserted will be
+     * stored in vals.
+     *
+     * @param transaction
+     *   The current active transaction.
+     * @param vals
+     *   The values to insert.
+     * @param can_replace
+     *   If true, then existing data can be rewritten, else data can only be added.
+     * @param station_can_add
+     *   If false, it will not create a missing station record, and only data
+     *   for existing stations can be added. If true, then if we are inserting
+     *   data for a station that does not yet exists in the database, it will
+     *   be created.
+     */
+    virtual void insert_station_data(dballe::Transaction& transaction, StationValues& vals, bool can_replace, bool station_can_add) = 0;
 
     /**
      * Insert data values into the database
@@ -333,7 +315,47 @@ public:
      *   data for a station that does not yet exists in the database, it will
      *   be created.
      */
-    virtual void insert_data(DataValues& vals, bool can_replace, bool station_can_add) = 0;
+    void insert_data(DataValues& vals, bool can_replace, bool station_can_add);
+
+    /**
+     * Insert data values into the database
+     *
+     * The IDs of the station andl all variables that were inserted will be
+     * stored in vals.
+     *
+     * @param transaction
+     *   The current active transaction.
+     * @param vals
+     *   The values to insert.
+     * @param can_replace
+     *   If true, then existing data can be rewritten, else data can only be added.
+     * @param station_can_add
+     *   If false, it will not create a missing station record, and only data
+     *   for existing stations can be added. If true, then if we are inserting
+     *   data for a station that does not yet exists in the database, it will
+     *   be created.
+     */
+    virtual void insert_data(dballe::Transaction& transaction, DataValues& vals, bool can_replace, bool station_can_add) = 0;
+
+    /**
+     * Remove data from the database
+     *
+     * @param query
+     *   The record with the query data (see technical specifications, par. 1.6.4
+     *   "parameter output/input") to select the items to be deleted
+     */
+    void remove_station_data(const Query& query);
+
+    /**
+     * Remove data from the database
+     *
+     * @param transaction
+     *   The current active transaction.
+     * @param query
+     *   The record with the query data (see technical specifications, par. 1.6.4
+     *   "parameter output/input") to select the items to be deleted
+     */
+    virtual void remove_station_data(dballe::Transaction& transaction, const Query& query) = 0;
 
     /**
      * Remove data from the database
@@ -342,16 +364,18 @@ public:
      *   The record with the query data (see technical specifications, par. 1.6.4
      *   "parameter output/input") to select the items to be deleted
      */
-    virtual void remove_station_data(const Query& query) = 0;
+    void remove(const Query& query);
 
     /**
      * Remove data from the database
      *
+     * @param transaction
+     *   The current active transaction.
      * @param rec
      *   The record with the query data (see technical specifications, par. 1.6.4
      *   "parameter output/input") to select the items to be deleted
      */
-    virtual void remove(const Query& rec) = 0;
+    virtual void remove(dballe::Transaction& transaction, const Query& rec) = 0;
 
     /**
      * Remove all data from the database.
@@ -359,7 +383,18 @@ public:
      * This is faster than remove() with an empty record, and unlike reset() it
      * preserves existing report information.
      */
-    virtual void remove_all() = 0;
+    void remove_all();
+
+    /**
+     * Remove all data from the database.
+     *
+     * This is faster than remove() with an empty record, and unlike reset() it
+     * preserves existing report information.
+     *
+     * @param transaction
+     *   The current active transaction.
+     */
+    virtual void remove_all(dballe::Transaction& transaction) = 0;
 
     /**
      * Perform database cleanup operations.
@@ -457,7 +492,19 @@ public:
      * @param attrs
      *   The attributes to be added
      */
-    virtual void attr_insert_station(int data_id, const Values& attrs) = 0;
+    void attr_insert_station(int data_id, const Values& attrs);
+
+    /**
+     * Insert new attributes on a station value
+     *
+     * @param transaction
+     *   The current active transaction.
+     * @param data_id
+     *   The id (returned by Cursor::attr_reference_id()) used to refer to the value
+     * @param attrs
+     *   The attributes to be added
+     */
+    virtual void attr_insert_station(dballe::Transaction& transaction, int data_id, const Values& attrs) = 0;
 
     /**
      * Insert new attributes on a data value
@@ -467,29 +514,67 @@ public:
      * @param attrs
      *   The attributes to be added
      */
-    virtual void attr_insert_data(int data_id, const Values& attrs) = 0;
+    void attr_insert_data(int data_id, const Values& attrs);
+
+    /**
+     * Insert new attributes on a data value
+     *
+     * @param transaction
+     *   The current active transaction.
+     * @param data_id
+     *   The id (returned by Cursor::attr_reference_id()) used to refer to the value
+     * @param attrs
+     *   The attributes to be added
+     */
+    virtual void attr_insert_data(dballe::Transaction& transaction, int data_id, const Values& attrs) = 0;
 
     /**
      * Delete attributes from a station value
      *
      * @param data_id
      *   The id (returned by Cursor::attr_reference_id()) used to refer to the value
-     * @param qcs
+     * @param attrs
      *   Array of WMO codes of the attributes to delete.  If empty, all attributes
      *   associated to the value will be deleted.
      */
-    virtual void attr_remove_station(int data_id, const db::AttrList& qcs) = 0;
+    void attr_remove_station(int data_id, const db::AttrList& attrs);
+
+    /**
+     * Delete attributes from a station value
+     *
+     * @param transaction
+     *   The current active transaction.
+     * @param data_id
+     *   The id (returned by Cursor::attr_reference_id()) used to refer to the value
+     * @param attrs
+     *   Array of WMO codes of the attributes to delete.  If empty, all attributes
+     *   associated to the value will be deleted.
+     */
+    virtual void attr_remove_station(dballe::Transaction& transaction, int data_id, const db::AttrList& attrs) = 0;
 
     /**
      * Delete attributes from a data value
      *
      * @param data_id
      *   The id (returned by Cursor::attr_reference_id()) used to refer to the value
-     * @param qcs
+     * @param attrs
      *   Array of WMO codes of the attributes to delete.  If empty, all attributes
      *   associated to the value will be deleted.
      */
-    virtual void attr_remove_data(int data_id, const db::AttrList& qcs) = 0;
+    void attr_remove_data(int data_id, const db::AttrList& attrs);
+
+    /**
+     * Delete attributes from a data value
+     *
+     * @param transaction
+     *   The current active transaction.
+     * @param data_id
+     *   The id (returned by Cursor::attr_reference_id()) used to refer to the value
+     * @param attrs
+     *   Array of WMO codes of the attributes to delete.  If empty, all attributes
+     *   associated to the value will be deleted.
+     */
+    virtual void attr_remove_data(dballe::Transaction& transaction, int data_id, const db::AttrList& attrs) = 0;
 
     /**
      * Check if this varcode and data_id correspond to a station variable. This
@@ -508,8 +593,6 @@ public:
     /**
      * Import a Message into the DB-All.e database
      *
-     * @param db
-     *   The DB-All.e database to write the data into
      * @param msg
      *   The Message containing the data to import
      * @param repmemo
@@ -519,13 +602,27 @@ public:
      *   Customise different aspects of the import process.  It is a bitmask of the
      *   various DBA_IMPORT_* macros.
      */
-    virtual void import_msg(const Message& msg, const char* repmemo, int flags) = 0;
+    void import_msg(const Message& msg, const char* repmemo, int flags);
+
+    /**
+     * Import a Message into the DB-All.e database
+     *
+     * @param transaction
+     *   The current active transaction.
+     * @param msg
+     *   The Message containing the data to import
+     * @param repmemo
+     *   Report mnemonic to which imported data belong.  If NULL is passed, then it
+     *   will be chosen automatically based on the message type.
+     * @param flags
+     *   Customise different aspects of the import process.  It is a bitmask of the
+     *   various DBA_IMPORT_* macros.
+     */
+    virtual void import_msg(dballe::Transaction& transaction, const Message& msg, const char* repmemo, int flags) = 0;
 
     /**
      * Import Messages into the DB-All.e database
      *
-     * @param db
-     *   The DB-All.e database to write the data into
      * @param msgs
      *   The Messages containing the data to import
      * @param repmemo
@@ -535,7 +632,23 @@ public:
      *   Customise different aspects of the import process.  It is a bitmask of the
      *   various DBA_IMPORT_* macros.
      */
-    virtual void import_msgs(const Messages& msgs, const char* repmemo, int flags);
+    void import_msgs(const Messages& msgs, const char* repmemo, int flags);
+
+    /**
+     * Import Messages into the DB-All.e database
+     *
+     * @param transaction
+     *   The current active transaction.
+     * @param msgs
+     *   The Messages containing the data to import
+     * @param repmemo
+     *   Report mnemonic to which imported data belong.  If NULL is passed, then it
+     *   will be chosen automatically based on the message type.
+     * @param flags
+     *   Customise different aspects of the import process.  It is a bitmask of the
+     *   various DBA_IMPORT_* macros.
+     */
+    virtual void import_msgs(dballe::Transaction& transaction, const Messages& msgs, const char* repmemo, int flags);
 
     /**
      * Perform the query in `query', and send the results to dest.
@@ -549,18 +662,35 @@ public:
      * @returns true if the query reached its end, false if it got interrupted
      *   because dest returned false.
      */
-    virtual bool export_msgs(const Query& query, std::function<bool(std::unique_ptr<Message>&&)> dest) = 0;
+    bool export_msgs(const Query& query, std::function<bool(std::unique_ptr<Message>&&)> dest);
+
+    /**
+     * Perform the query in `query', and send the results to dest.
+     *
+     * Return false from dest to interrupt the query.
+     *
+     * @param transaction
+     *   The current active transaction.
+     * @param query
+     *   The query to perform
+     * @param dest
+     *   The function that will handle the resulting messages
+     * @returns true if the query reached its end, false if it got interrupted
+     *   because dest returned false.
+     */
+    virtual bool export_msgs(dballe::Transaction& transaction, const Query& query, std::function<bool(std::unique_ptr<Message>&&)> dest) = 0;
 
     /**
      * Dump the entire contents of the database to an output stream
      */
     virtual void dump(FILE* out) = 0;
 
+    /// Print informations about the database to the given output stream
+    virtual void print_info(FILE* out);
+
     /// Return the default repinfo file pathname
     static const char* default_repinfo_file();
 };
 
 }
-
-/* vim:set ts=4 sw=4: */
 #endif
