@@ -1,11 +1,12 @@
 #include "cursor.h"
 #include "qbuilder.h"
 #include "db.h"
-#include <dballe/db/sql/driver.h>
-#include "dballe/db/sql/repinfo.h"
-#include "dballe/db/sql/station.h"
-#include "dballe/db/sql/levtr.h"
-#include "dballe/db/sql/datav6.h"
+#include <dballe/sql/sql.h>
+#include <dballe/db/v6/driver.h>
+#include "dballe/db/v6/repinfo.h"
+#include "dballe/db/v6/station.h"
+#include "dballe/db/v6/levtr.h"
+#include "dballe/db/v6/datav6.h"
 #include "dballe/types.h"
 #include "dballe/record.h"
 #include "dballe/var.h"
@@ -57,7 +58,7 @@ struct Base : public Interface
     const unsigned int modifiers;
 
     /// Results from the query
-    Structbuf<sql::SQLRecordV6> results;
+    Structbuf<v6::SQLRecordV6> results;
 
     /// Current result element being iterated
     int cur = -1;
@@ -126,7 +127,7 @@ struct Base : public Interface
     /// Run the query in qb and fill results with its output
     virtual void load(const QueryBuilder& qb)
     {
-        db.driver().run_built_query_v6(qb, [&](sql::SQLRecordV6& rec) {
+        db.driver().run_built_query_v6(qb, [&](v6::SQLRecordV6& rec) {
             results.append(rec);
         });
         // We are done adding, prepare the structbuf for reading
@@ -233,10 +234,7 @@ struct StationData : public Base<CursorStationData>
     {
         to_record_pseudoana(rec);
         to_record_repinfo(rec);
-        if (results[cur].out_id_ltr == -1)
-            rec.unset("context_id");
-        else
-            rec.seti("context_id", results[cur].out_id_data);
+        rec.seti("context_id", results[cur].out_id_data);
         to_record_varcode(rec);
         rec.clear_vars();
         rec.set(newvar(results[cur].out_varcode, results[cur].out_value));
@@ -276,10 +274,7 @@ struct Data : public Base<CursorData>
     {
         to_record_pseudoana(rec);
         to_record_repinfo(rec);
-        if (results[cur].out_id_ltr == -1)
-            rec.unset("context_id");
-        else
-            rec.seti("context_id", results[cur].out_id_data);
+        rec.seti("context_id", results[cur].out_id_data);
         to_record_varcode(rec);
         to_record_ltr(rec);
         to_record_datetime(rec);
@@ -430,11 +425,11 @@ struct Best : public Base<CursorData>
 
     void load(const QueryBuilder& qb) override
     {
-        db::sql::Repinfo& ri = db.repinfo();
+        db::v6::Repinfo& ri = db.repinfo();
         bool first = true;
-        sql::SQLRecordV6 best;
+        v6::SQLRecordV6 best;
 
-        db.driver().run_built_query_v6(qb, [&](sql::SQLRecordV6& rec) {
+        db.driver().run_built_query_v6(qb, [&](v6::SQLRecordV6& rec) {
             // Fill priority
             rec.priority = ri.get_priority(rec.out_rep_cod);
 
@@ -479,7 +474,7 @@ unique_ptr<CursorStation> run_station_query(DB& db, const core::Query& q, bool e
     if (explain)
     {
         fprintf(stderr, "EXPLAIN "); q.print(stderr);
-        db.driver().explain(qb.sql_query);
+        db.conn->explain(qb.sql_query, stderr);
     }
 
     auto resptr = new Stations(db, modifiers);
@@ -497,7 +492,7 @@ unique_ptr<CursorStationData> run_station_data_query(DB& db, const core::Query&
     if (explain)
     {
         fprintf(stderr, "EXPLAIN "); q.print(stderr);
-        db.driver().explain(qb.sql_query);
+        db.conn->explain(qb.sql_query, stderr);
     }
 
     unique_ptr<CursorStationData> res;
@@ -524,7 +519,7 @@ unique_ptr<CursorData> run_data_query(DB& db, const core::Query& q, bool explain
     if (explain)
     {
         fprintf(stderr, "EXPLAIN "); q.print(stderr);
-        db.driver().explain(qb.sql_query);
+        db.conn->explain(qb.sql_query, stderr);
     }
 
     unique_ptr<CursorData> res;
@@ -553,7 +548,7 @@ unique_ptr<CursorSummary> run_summary_query(DB& db, const core::Query& q, bool e
     if (explain)
     {
         fprintf(stderr, "EXPLAIN "); q.print(stderr);
-        db.driver().explain(qb.sql_query);
+        db.conn->explain(qb.sql_query, stderr);
     }
 
     auto resptr = new Summary(db, modifiers);
@@ -574,7 +569,7 @@ void run_delete_query(DB& db, const core::Query& q, bool station_vars, bool expl
     if (explain)
     {
         fprintf(stderr, "EXPLAIN "); q.print(stderr);
-        db.driver().explain(qb.sql_query);
+        db.conn->explain(qb.sql_query, stderr);
     }
 
     db.data().remove(qb);
