@@ -1,24 +1,3 @@
-/*
- * dballe/v6/db - Archive for point-based meteorological data, db layout version 6
- *
- * Copyright (C) 2005--2014  ARPA-SIM <urpsim@smr.arpa.emr.it>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
- *
- * Author: Enrico Zini <enrico@enricozini.com>
- */
-
 #ifndef DBA_DB_V6_H
 #define DBA_DB_V6_H
 
@@ -29,47 +8,20 @@
 #include <vector>
 #include <memory>
 
-/** @file
- * @ingroup db
- *
- * Functions used to connect to DB-All.e and insert, query and delete data.
- */
-
-/**
- * Constants used to define what values we should retrieve from a query
- */
-/** Retrieve latitude and longitude */
-#define DBA_DB_WANT_COORDS      (1 << 0)
-/** Retrieve the mobile station identifier */
-#define DBA_DB_WANT_IDENT       (1 << 1)
-/** Retrieve the level information */
-#define DBA_DB_WANT_LEVEL       (1 << 2)
-/** Retrieve the time range information */
-#define DBA_DB_WANT_TIMERANGE   (1 << 3)
-/** Retrieve the date and time information */
-#define DBA_DB_WANT_DATETIME    (1 << 4)
-/** Retrieve the variable name */
-#define DBA_DB_WANT_VAR_NAME    (1 << 5)
-/** Retrieve the variable value */
-#define DBA_DB_WANT_VAR_VALUE   (1 << 6)
-/** Retrieve the report code */
-#define DBA_DB_WANT_REPCOD      (1 << 7)
-/** Retrieve the station ID */
-#define DBA_DB_WANT_ANA_ID      (1 << 8)
-/** Retrieve the lev_tr ID */
-#define DBA_DB_WANT_CONTEXT_ID  (1 << 9)
-
 namespace dballe {
 struct Station;
 struct StationValues;
 struct DataValues;
 
-namespace db {
+namespace sql {
 struct Connection;
 struct Statement;
 struct Sequence;
+}
 
-namespace sql {
+namespace db {
+
+namespace v6 {
 struct Driver;
 struct Repinfo;
 struct Station;
@@ -82,13 +34,13 @@ struct AttrV6;
 namespace v6 {
 
 /**
- * DB-ALLe database connection
+ * DB-ALLe database connection, database format V6
  */
 class DB : public dballe::DB
 {
 public:
     /// Database connection
-    db::Connection* conn;
+    dballe::sql::Connection* conn;
     /// Database query tracing
     Trace trace;
     /// True if we print an EXPLAIN trace of all queries to stderr
@@ -96,7 +48,7 @@ public:
 
 protected:
     /// SQL driver backend
-    sql::Driver* m_driver;
+    v6::Driver* m_driver;
 
     /**
      * Accessors for the various parts of the database.
@@ -106,22 +58,22 @@ protected:
      * @{
      */
     /** Report information */
-    struct sql::Repinfo* m_repinfo;
+    struct v6::Repinfo* m_repinfo;
     /** Station information */
-    struct sql::Station* m_station;
+    struct v6::Station* m_station;
     /** Level/timerange information */
-    struct sql::LevTr* m_lev_tr;
+    struct v6::LevTr* m_lev_tr;
     /// Level/timerange cache
-    struct sql::LevTrCache* m_lev_tr_cache;
+    struct v6::LevTrCache* m_lev_tr_cache;
     /** Variable data */
-    struct sql::DataV6* m_data;
+    struct v6::DataV6* m_data;
     /** Variable attributes */
-    struct sql::AttrV6* m_attr;
+    struct v6::AttrV6* m_attr;
     /** @} */
 
     void init_after_connect();
 
-    DB(std::unique_ptr<Connection> conn);
+    DB(std::unique_ptr<dballe::sql::Connection> conn);
 
     /*
      * Lookup, insert or replace data in station taking the values from
@@ -137,7 +89,7 @@ protected:
      * @returns
      *   The station ID
      */
-    int obtain_station(const Station& st, bool can_add=true);
+    int obtain_station(const dballe::Station& st, bool can_add=true);
 
 public:
     virtual ~DB();
@@ -145,25 +97,27 @@ public:
     db::Format format() const { return V6; }
 
     /// Access the backend DB driver
-    sql::Driver& driver();
+    v6::Driver& driver();
 
     /// Access the repinfo table
-    sql::Repinfo& repinfo();
+    v6::Repinfo& repinfo();
 
     /// Access the station table
-    sql::Station& station();
+    v6::Station& station();
 
     /// Access the lev_tr table
-    sql::LevTr& lev_tr();
+    v6::LevTr& lev_tr();
 
     /// Access the lev_tr cache
-    sql::LevTrCache& lev_tr_cache();
+    v6::LevTrCache& lev_tr_cache();
 
     /// Access the data table
-    sql::DataV6& data();
+    v6::DataV6& data();
 
     /// Access the data table
-    sql::AttrV6& attr();
+    v6::AttrV6& attr();
+
+    std::unique_ptr<dballe::Transaction> transaction() override;
 
     void disappear();
 
@@ -211,12 +165,12 @@ public:
      */
     int rep_cod_from_memo(const char* memo);
 
-    void insert_station_data(StationValues& vals, bool can_replace, bool station_can_add) override;
-    void insert_data(DataValues& vals, bool can_replace, bool station_can_add) override;
+    void insert_station_data(dballe::Transaction& transaction, StationValues& vals, bool can_replace, bool station_can_add) override;
+    void insert_data(dballe::Transaction& transaction, DataValues& vals, bool can_replace, bool station_can_add) override;
 
-    void remove_station_data(const Query& query) override;
-    void remove(const Query& query);
-    void remove_all();
+    void remove_station_data(dballe::Transaction& transaction, const Query& query) override;
+    void remove(dballe::Transaction& transaction, const Query& query);
+    void remove_all(dballe::Transaction& transaction);
 
     /**
      * Remove orphan values from the database.
@@ -236,14 +190,14 @@ public:
 
     void attr_query_station(int data_id, std::function<void(std::unique_ptr<wreport::Var>)>&& dest) override;
     void attr_query_data(int data_id, std::function<void(std::unique_ptr<wreport::Var>)>&& dest) override;
-    void attr_insert_station(int data_id, const Values& attrs) override;
-    void attr_insert_data(int data_id, const Values& attrs) override;
-    void attr_remove_station(int data_id, const db::AttrList& qcs) override;
-    void attr_remove_data(int data_id, const db::AttrList& qcs) override;
+    void attr_insert_station(dballe::Transaction& transaction, int data_id, const Values& attrs) override;
+    void attr_insert_data(dballe::Transaction& transaction, int data_id, const Values& attrs) override;
+    void attr_remove_station(dballe::Transaction& transaction, int data_id, const db::AttrList& qcs) override;
+    void attr_remove_data(dballe::Transaction& transaction, int data_id, const db::AttrList& qcs) override;
     bool is_station_variable(int data_id, wreport::Varcode varcode) override;
 
-    void import_msg(const Message& msg, const char* repmemo, int flags) override;
-    bool export_msgs(const Query& query, std::function<bool(std::unique_ptr<Message>&&)> dest) override;
+    void import_msg(dballe::Transaction& transaction, const Message& msg, const char* repmemo, int flags) override;
+    bool export_msgs(dballe::Transaction& transaction, const Query& query, std::function<bool(std::unique_ptr<Message>&&)> dest) override;
 
     /**
      * Dump the entire contents of the database to an output stream
@@ -253,9 +207,7 @@ public:
     friend class dballe::DB;
 };
 
-} // namespace v6
-} // namespace db
-} // namespace dballe
-
-/* vim:set ts=4 sw=4: */
+}
+}
+}
 #endif
