@@ -1,11 +1,12 @@
 #include "db.h"
 #include "cursor.h"
 #include "qbuilder.h"
-#include "dballe/db/sql/driver.h"
-#include "dballe/db/sql/repinfo.h"
-#include "dballe/db/sql/station.h"
-#include "dballe/db/sql/levtr.h"
-#include "dballe/db/sql/attrv6.h"
+#include "dballe/sql/sql.h"
+#include "dballe/db/v6/driver.h"
+#include "dballe/db/v6/repinfo.h"
+#include "dballe/db/v6/station.h"
+#include "dballe/db/v6/levtr.h"
+#include "dballe/db/v6/attrv6.h"
 #include "dballe/msg/msg.h"
 #include "dballe/msg/context.h"
 #include "dballe/core/query.h"
@@ -16,6 +17,7 @@
 
 using namespace wreport;
 using namespace std;
+using dballe::sql::Connection;
 
 namespace dballe {
 namespace db {
@@ -57,18 +59,16 @@ struct StationLayerCache : protected std::vector<wreport::Var*>
 
 }
 
-bool DB::export_msgs(const dballe::Query& query, std::function<bool(std::unique_ptr<Message>&&)> dest)
+bool DB::export_msgs(dballe::Transaction& transaction, const dballe::Query& query, std::function<bool(std::unique_ptr<Message>&&)> dest)
 {
     auto tr = trace.trace_export_msgs(query);
-    sql::Repinfo& ri = repinfo();
-    sql::AttrV6& at = attr();
-    sql::LevTrCache& ltrc = lev_tr_cache();
+    v6::Repinfo& ri = repinfo();
+    v6::AttrV6& at = attr();
+    v6::LevTrCache& ltrc = lev_tr_cache();
 
     // Message being built
     unique_ptr<Msg> msg;
 
-    auto t = conn->transaction();
-
     // The big export query
     DataQueryBuilder qb(*this, core::Query::downcast(query), DBA_DB_MODIFIER_SORT_FOR_EXPORT, false);
     qb.build();
@@ -82,15 +82,15 @@ bool DB::export_msgs(const dballe::Query& query, std::function<bool(std::unique_
 
     // Retrieve results, buffering them locally to avoid performing concurrent
     // queries
-    Structbuf<sql::SQLRecordV6> results;
-    driver().run_built_query_v6(qb, [&](sql::SQLRecordV6& sqlrec) {
+    Structbuf<v6::SQLRecordV6> results;
+    driver().run_built_query_v6(qb, [&](v6::SQLRecordV6& sqlrec) {
         results.append(sqlrec);
     });
     results.ready_to_read();
 
     for (unsigned row = 0; row < results.size(); ++row)
     {
-        const sql::SQLRecordV6& sqlrec = results[row];
+        const v6::SQLRecordV6& sqlrec = results[row];
 
         //TRACE("Got B%02d%03d %ld,%ld, %ld,%ld %ld,%ld,%ld %s\n",
         //        WR_VAR_X(sqlrec.out_varcode), WR_VAR_Y(sqlrec.out_varcode),
@@ -101,7 +101,7 @@ bool DB::export_msgs(const dballe::Query& query, std::function<bool(std::unique_
         unique_ptr<Var> var(newvar(sqlrec.out_varcode, sqlrec.out_value));
 
         /* Load the attributes from the database */
-        at.read(sqlrec.out_id_data, [&](unique_ptr<Var> attr) { var->seta(auto_ptr<Var>(attr.release())); });
+        at.read(sqlrec.out_id_data, [&](unique_ptr<Var> attr) { var->seta(move(attr)); });
 
         /* See if we have the start of a new message */
         if (sqlrec.out_ana_id != last_ana_id
@@ -159,7 +159,7 @@ bool DB::export_msgs(const dballe::Query& query, std::function<bool(std::unique_
             last_rep_cod = sqlrec.out_rep_cod;
         }
 
-        TRACE("Inserting var B%02d%03d (%s)\n", WR_VAR_X(var->code()), WR_VAR_Y(var->code()), var->value());
+        TRACE("Inserting var %01d%02d%03d (%s)\n", WR_VAR_FXY(var->code()), var->enqc());
         if (sqlrec.out_id_ltr == -1)
         {
             msg->set(move(var), Level(), Trange());
@@ -187,7 +187,6 @@ bool DB::export_msgs(const dballe::Query& query, std::function<bool(std::unique_
     }
 
     // Useful for Oracle to end the session
-    t->commit();
     tr->done();
     return true;
 }
