@@ -1,41 +1,22 @@
-/*
- * db/v6/import - Import Msg data into the database
- *
- * Copyright (C) 2005--2015  ARPA-SIM <urpsim@smr.arpa.emr.it>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
- *
- * Author: Enrico Zini <enrico@enricozini.com>
- */
-
 #include "db.h"
-#include "dballe/db/sql.h"
-#include "dballe/db/sql/driver.h"
-#include "dballe/db/sql/station.h"
-#include "dballe/db/sql/levtr.h"
-#include "dballe/db/sql/datav6.h"
-#include "dballe/db/sql/attrv6.h"
+#include "dballe/sql/sql.h"
+#include "dballe/db/v6/driver.h"
+#include "dballe/db/v6/station.h"
+#include "dballe/db/v6/levtr.h"
+#include "dballe/db/v6/datav6.h"
+#include "dballe/db/v6/attrv6.h"
 #include "dballe/msg/msg.h"
 #include "dballe/msg/context.h"
+#include <cassert>
 
 using namespace wreport;
+using dballe::sql::Connection;
 
 namespace dballe {
 namespace db {
 namespace v6 {
 
-void DB::import_msg(const Message& message, const char* repmemo, int flags)
+void DB::import_msg(dballe::Transaction& transaction, const Message& message, const char* repmemo, int flags)
 {
     const Msg& msg = Msg::downcast(message);
     const msg::Context* l_ana = msg.find_context(Level(), Trange());
@@ -45,13 +26,13 @@ void DB::import_msg(const Message& message, const char* repmemo, int flags)
 	// Check if the station is mobile
     bool mobile = msg.get_ident_var() != NULL;
 
-    sql::Station& st = station();
-    sql::LevTr& lt = lev_tr();
-    sql::DataV6& dd = data();
-    sql::AttrV6& dq = attr();
+    v6::Station& st = station();
+    v6::LevTr& lt = lev_tr();
+    v6::DataV6& dd = data();
+    v6::AttrV6& dq = attr();
 
-    // Begin transaction
-    auto t = conn->transaction();
+    dballe::sql::Transaction* t = dynamic_cast<dballe::sql::Transaction*>(&transaction);
+    assert(t);
 
     // Fill up the pseudoana informations needed to fetch an existing ID
 
@@ -97,7 +78,7 @@ void DB::import_msg(const Message& message, const char* repmemo, int flags)
     if ((flags & DBA_IMPORT_FULL_PSEUDOANA) || inserted_pseudoana)
     {
         // Prepare a bulk insert
-        sql::bulk::InsertV6 vars;
+        v6::bulk::InsertV6 vars;
         vars.id_station = id_station;
         vars.id_report = id_report;
         vars.datetime = Datetime(1000, 1, 1, 0, 0, 0);
@@ -111,7 +92,7 @@ void DB::import_msg(const Message& message, const char* repmemo, int flags)
         }
 
         // Run the bulk insert
-        dd.insert(*t, vars, (flags & DBA_IMPORT_OVERWRITE) ? sql::DataV6::UPDATE : sql::DataV6::IGNORE);
+        dd.insert(*t, vars, (flags & DBA_IMPORT_OVERWRITE) ? v6::DataV6::UPDATE : v6::DataV6::IGNORE);
 
         // Insert the attributes
         if (flags & DBA_IMPORT_ATTRS)
@@ -121,27 +102,22 @@ void DB::import_msg(const Message& message, const char* repmemo, int flags)
                 if (v.inserted())
                     dq.add(v.id_data, *v.var);
 #else
-            sql::bulk::InsertAttrsV6 attrs;
+            v6::bulk::InsertAttrsV6 attrs;
             for (const auto& v: vars)
             {
                 if (!v.inserted()) continue;
                 attrs.add_all(*v.var, v.id_data);
             }
             if (!attrs.empty())
-                dq.insert(*t, attrs, sql::AttrV6::UPDATE);
+                dq.insert(*t, attrs, v6::AttrV6::UPDATE);
 #endif
         }
     }
 
-    sql::bulk::InsertV6 vars;
+    v6::bulk::InsertV6 vars;
     vars.id_station = id_station;
     vars.id_report = id_report;
 
-    // Date and time
-    if (msg.get_datetime().is_missing())
-        throw error_notfound("date/time informations not found (or incomplete) in message to insert");
-    vars.datetime = msg.get_datetime();
-
     // Fill the bulk insert with the rest of the data
     for (size_t i = 0; i < msg.data.size(); ++i)
     {
@@ -151,6 +127,14 @@ void DB::import_msg(const Message& message, const char* repmemo, int flags)
         // Skip the station info level
         if (is_ana_level) continue;
 
+        // Date and time
+        if (vars.datetime.is_missing())
+        {
+            vars.datetime = msg.get_datetime();
+            if (vars.datetime.is_missing())
+                throw error_notfound("date/time informations not found (or incomplete) in message to insert");
+        }
+
         // Get the database ID of the lev_tr
         int id_lev_tr = lt.obtain_id(ctx.level, ctx.trange);
 
@@ -163,7 +147,7 @@ void DB::import_msg(const Message& message, const char* repmemo, int flags)
     }
 
     // Run the bulk insert
-    dd.insert(*t, vars, (flags & DBA_IMPORT_OVERWRITE) ? sql::DataV6::UPDATE : sql::DataV6::IGNORE);
+    dd.insert(*t, vars, (flags & DBA_IMPORT_OVERWRITE) ? v6::DataV6::UPDATE : v6::DataV6::IGNORE);
 
     // Insert the attributes
     if (flags & DBA_IMPORT_ATTRS)
@@ -173,18 +157,16 @@ void DB::import_msg(const Message& message, const char* repmemo, int flags)
             if (v.inserted())
                 dq.add(v.id_data, *v.var);
 #else
-        sql::bulk::InsertAttrsV6 attrs;
+        v6::bulk::InsertAttrsV6 attrs;
         for (const auto& v: vars)
         {
             if (!v.inserted()) continue;
             attrs.add_all(*v.var, v.id_data);
         }
         if (!attrs.empty())
-            dq.insert(*t, attrs, sql::AttrV6::UPDATE);
+            dq.insert(*t, attrs, v6::AttrV6::UPDATE);
 #endif
     }
-
-    t->commit();
 }
 
 }
