@@ -1,69 +1,6 @@
-/*
- * dballe/msg - Hold an interpreted weather bulletin
- *
- * Copyright (C) 2005--2015  ARPA-SIM <urpsim@smr.arpa.emr.it>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
- *
- * Author: Enrico Zini <enrico@enricozini.com>
- */
-
 #ifndef DBA_MSG_H
 #define DBA_MSG_H
 
-/** @file
- * @ingroup msg
- *
- * Abstraction for a weather report message which is independent from the
- * encoding, used to make sense of decoded information and to carry data between
- * the various import and export modules of DB-ALLe.
- * 
- * The internal representation is as connected as possible to physics rather than
- * to observations.  dba_msg is a container for related weather information,
- * stored in a nonambiguous way.
- *
- * To understand what is the difference betwee ::dba_msg and other ways of
- * representing weather data, it is important to keep in mind how a value is
- * usually defined in the various encodings:
- * 
- * \li by previous values and position, as in the AOF encoding
- * \li by previous values, data descriptor and sometimes position, as in the BUFR
- *     encoding
- * \li by measure type and physical coordinates, as in ::dba_msg and the DB-ALLe
- *     database
- * 
- * ::dba_msg contains values as tuples (variable, level layer, time range).
- * 
- * The variable is represented by a dba_var.  The dba_varcode of the dba_var
- * refers to a local B table which lists physical measurements unambiguously.
- * 
- * Level layer is a triple (level type, l1, l2) and time range is a triple
- * (pindicator, p1, p2).  The values of these two triples follow what is used in
- * the GRIB encoding plus some local extensions, and an explanation of their
- * possible value is found in the document "DB-ALLe Guide of the Fortran API".
- * 
- * Importers and exporters have to implement a mapping between their
- * representation and the unambiguous physical representation.  Luckily this is
- * necessarily possible, because the ultimate purpose of the various message
- * encodings is to correctly transmit those physical data.
- *
- * Since to work with the full physical coordinates one needs to specify a lot of
- * different parameters in order to identify a value (BLocal value, level layer,
- * time range), there is a var.h module available with shortcut functions to
- * the values that are used more commonly.
- */
-
 #include <dballe/message.h>
 #include <dballe/var.h>
 #include <dballe/core/defs.h>
@@ -77,9 +14,9 @@
 struct lua_State;
 
 namespace dballe {
-
 struct Record;
 struct CSVReader;
+struct CSVWriter;
 
 namespace msg {
 struct Context;
@@ -94,7 +31,7 @@ Messages messages_from_csv(CSVReader& in);
 /**
  * Output in CSV format
  */
-void messages_to_csv(const Messages& msgs, std::ostream& out);
+void messages_to_csv(const Messages& msgs, CSVWriter& out);
 
 }
 
@@ -139,7 +76,7 @@ protected:
     int find_index(const Level& lev, const Trange& tr) const;
 
     /// Sensor network of origin of the Msg contents
-    std::string m_network;
+    std::string m_rep_memo;
     /// Reference coordinates for the Msg contents
     Coords m_coords;
     /// Identifier of the contents originator
@@ -188,6 +125,9 @@ public:
     void print(FILE* out) const override;
     unsigned diff(const Message& msg) const override;
 
+    void set_rep_memo(const std::string& r) { m_rep_memo = r; }
+    void set_coords(const Coords& c) { m_coords = c; }
+    void set_ident(const Ident& i) { m_ident = i; }
     void set_datetime(const Datetime& dt) { m_datetime = dt; }
 
     /// Remove all information from Msg
@@ -259,7 +199,7 @@ public:
      * Find a variable given its description
      *
      * @param code
-     *   The ::dba_varcode of the variable to query. See @ref vartable.h
+     *   The wreport::Varcode of the variable to query.
      * @param lev
      *   The Level to query
      * @param tr
@@ -273,7 +213,7 @@ public:
      * Remove a variable given its description
      *
      * @param code
-     *   The ::dba_varcode of the variable to query. See @ref vartable.h
+     *   The wreport::Varcode of the variable to query.
      * @param lev
      *   The Level to query
      * @param tr
@@ -286,10 +226,8 @@ public:
     /** 
      * Find a datum given its shortcut ID
      *
-     * @param msg
-     *   The message to query
      * @param id
-     *   Shortcut ID of the value to set (see @ref vars.h)
+     *   Shortcut ID of the value to set.
      * @return
      *   The value found, or NULL if it was not found.
      */
@@ -298,8 +236,6 @@ public:
     /** 
      * Find a contexts given level and timerange found in a shortcut ID
      *
-     * @param msg
-     *   The message to query
      * @param id
      *   Shortcut ID with the level information to use
      * @return
@@ -310,10 +246,8 @@ public:
     /** 
      * Find a datum given its shortcut ID
      *
-     * @param msg
-     *   The message to query
      * @param id
-     *   Shortcut ID of the value to set (see @ref vars.h)
+     *   Shortcut ID of the value to set.
      * @return
      *   The value found, or NULL if it was not found.
      */
@@ -348,7 +282,7 @@ public:
      * Add or replace a value, taking ownership of the source variable without
      * copying it.
      *
-     * @param msg
+     * @param var
      *   The Var with the value to set.  This Msg will take ownership of memory
      *   management.
      * @param lev
@@ -450,13 +384,11 @@ public:
      */
     bool from_csv(CSVReader& in);
 
-    /**
-     * Output in CSV format
-     */
-    void to_csv(std::ostream& out) const;
+    /// Output in CSV format
+    void to_csv(CSVWriter& out) const;
 
     /// Output the CSV header
-    static void csv_header(std::ostream& out);
+    static void csv_header(CSVWriter& out);
 
     /**
      * Get the message source type corresponding to the given report code
