@@ -1,4 +1,4 @@
-/* C++ code produced by gperf version 3.0.3 */
+/* C++ code produced by gperf version 3.0.4 */
 /* Command-line: gperf  */
 /* Computed positions: -k'1,6-7,9,11,$' */
 
@@ -304,41 +304,41 @@ int resolve_var_substring(const char* name, int len)
 
 
 struct MsgVarShortcut shortcutTable[] = {
- { WR_VAR(0, 1, 1), 257, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
- { WR_VAR(0, 1, 2), 257, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
- { WR_VAR(0, 1, 8), 257, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
- { WR_VAR(0, 1, 11), 257, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
- { WR_VAR(0, 1, 19), 257, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
- { WR_VAR(0, 1, 63), 257, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
- { WR_VAR(0, 1, 194), 257, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
- { WR_VAR(0, 1, 212), 257, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
- { WR_VAR(0, 1, 213), 257, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
- { WR_VAR(0, 1, 214), 257, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
- { WR_VAR(0, 1, 215), 257, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
- { WR_VAR(0, 1, 216), 257, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
- { WR_VAR(0, 1, 217), 257, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
- { WR_VAR(0, 2, 1), 257, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
- { WR_VAR(0, 2, 2), 257, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
- { WR_VAR(0, 2, 5), 257, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
- { WR_VAR(0, 2, 61), 257, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
- { WR_VAR(0, 2, 62), 257, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
- { WR_VAR(0, 2, 63), 257, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
- { WR_VAR(0, 2, 70), 257, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
- { WR_VAR(0, 4, 1), 257, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
- { WR_VAR(0, 4, 2), 257, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
- { WR_VAR(0, 4, 3), 257, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
- { WR_VAR(0, 4, 4), 257, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
- { WR_VAR(0, 4, 5), 257, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
- { WR_VAR(0, 4, 6), 257, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
- { WR_VAR(0, 5, 1), 257, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
- { WR_VAR(0, 6, 1), 257, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
- { WR_VAR(0, 7, 4), 257, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
- { WR_VAR(0, 7, 7), 257, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
- { WR_VAR(0, 7, 30), 257, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
- { WR_VAR(0, 7, 31), 257, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
- { WR_VAR(0, 8, 4), 257, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
- { WR_VAR(0, 8, 21), 257, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
- { WR_VAR(0, 33, 24), 257, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
+ { WR_VAR(0, 1, 1), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
+ { WR_VAR(0, 1, 2), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
+ { WR_VAR(0, 1, 8), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
+ { WR_VAR(0, 1, 11), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
+ { WR_VAR(0, 1, 19), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
+ { WR_VAR(0, 1, 63), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
+ { WR_VAR(0, 1, 194), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
+ { WR_VAR(0, 1, 212), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
+ { WR_VAR(0, 1, 213), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
+ { WR_VAR(0, 1, 214), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
+ { WR_VAR(0, 1, 215), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
+ { WR_VAR(0, 1, 216), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
+ { WR_VAR(0, 1, 217), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
+ { WR_VAR(0, 2, 1), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
+ { WR_VAR(0, 2, 2), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
+ { WR_VAR(0, 2, 5), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
+ { WR_VAR(0, 2, 61), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
+ { WR_VAR(0, 2, 62), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
+ { WR_VAR(0, 2, 63), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
+ { WR_VAR(0, 2, 70), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
+ { WR_VAR(0, 4, 1), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
+ { WR_VAR(0, 4, 2), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
+ { WR_VAR(0, 4, 3), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
+ { WR_VAR(0, 4, 4), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
+ { WR_VAR(0, 4, 5), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
+ { WR_VAR(0, 4, 6), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
+ { WR_VAR(0, 5, 1), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
+ { WR_VAR(0, 6, 1), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
+ { WR_VAR(0, 7, 4), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
+ { WR_VAR(0, 7, 7), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
+ { WR_VAR(0, 7, 30), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
+ { WR_VAR(0, 7, 31), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
+ { WR_VAR(0, 8, 4), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
+ { WR_VAR(0, 8, 21), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
+ { WR_VAR(0, 33, 24), MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT, MISSING_INT },
  { WR_VAR(0, 20, 10), 256, MISSING_INT, MISSING_INT, MISSING_INT, 254, 0, 0 },
  { WR_VAR(0, 20, 11), 256, MISSING_INT, 259, 4, 254, 0, 0 },
  { WR_VAR(0, 20, 12), 256, MISSING_INT, 259, 4, 254, 0, 0 },
@@ -364,8 +364,8 @@ struct MsgVarShortcut shortcutTable[] = {
  { WR_VAR(0, 11, 41), 103, 10000, MISSING_INT, MISSING_INT, 254, 0, 0 },
  { WR_VAR(0, 11, 43), 103, 10000, MISSING_INT, MISSING_INT, 254, 0, 0 },
  { WR_VAR(0, 10, 52), 103, 2000, MISSING_INT, MISSING_INT, 254, 0, 0 },
- { WR_VAR(0, 12, 2), 103, 2000, MISSING_INT, MISSING_INT, 254, 0, 0 },
  { WR_VAR(0, 12, 101), 103, 2000, MISSING_INT, MISSING_INT, 254, 0, 0 },
+ { WR_VAR(0, 12, 102), 103, 2000, MISSING_INT, MISSING_INT, 254, 0, 0 },
  { WR_VAR(0, 12, 103), 103, 2000, MISSING_INT, MISSING_INT, 254, 0, 0 },
  { WR_VAR(0, 13, 3), 103, 2000, MISSING_INT, MISSING_INT, 254, 0, 0 },
  { WR_VAR(0, 10, 51), 101, MISSING_INT, MISSING_INT, MISSING_INT, 254, 0, 0 },
