@@ -109,7 +109,7 @@ class Tests : public TestCase
         });
         add_method("reproduce_temp", []() {
             // Export a well known TEMP which used to fail
-            Messages msgs = read_msgs_csv("csv/temp1.csv");
+            Messages msgs = wcallchecked(read_msgs_csv("csv/temp1.csv"));
             wassert(actual(msgs.size()) > 0);
 
             // Replace with packed levels because comparison later happens against
@@ -263,10 +263,14 @@ class Tests : public TestCase
         });
         add_testcodec("synop-rad2.bufr", [](TestCodec& test) {
             // Test import/export of GTS synop without pressure of standard level
-            // FIXME: currently fails
             test.expected_template = "synop-wmo";
             test.expected_min_vars = 50;
-            //test.verbose = true;
+            test.after_reimport_import.add(new dballe::tests::tweaks::RemoveContext(Level(1), Trange(1, 0, 21600)));
+            test.after_reimport_import.add(new dballe::tests::tweaks::RemoveContext(Level(1), Trange(1, 0, 43200)));
+            test.after_reimport_import.add(new dballe::tests::tweaks::StripVars{WR_VAR(0, 11, 41), WR_VAR(0, 11, 43)});
+            test.after_convert_import.add(new dballe::tests::tweaks::RemoveContext(Level(1), Trange(1, 0, 21600)));
+            test.after_convert_import.add(new dballe::tests::tweaks::RemoveContext(Level(1), Trange(1, 0, 43200)));
+            test.after_convert_import.add(new dballe::tests::tweaks::RemoveContext(Level(103, 10000), Trange(205, 0, 10800)));
 
             wassert(test.run_reimport());
             wassert(test.run_convert("synop-wmo"));
@@ -278,15 +282,6 @@ class Tests : public TestCase
             wassert(test.run_reimport());
             wassert(test.run_convert("synop-wmo"));
         });
-        add_testcodec("temp-timesig18.bufr", [](TestCodec& test) {
-            // FIXME: temp message with data category 0: what do we do with it?
-            // FIXME: currently fails
-            test.expected_min_vars = 50;
-            test.expected_template = "temp-wmo";
-
-            wassert(test.run_reimport());
-            wassert(test.run_convert("temp-wmo"));
-        });
         add_testcodec("obs2-101.16.bufr", [](TestCodec& test) {
             // Re-export test for old style temps
             wassert(test.run_reimport());
@@ -461,17 +456,6 @@ class Tests : public TestCase
             //run_test(test, do_test, "acars-wmo");
         });
 #endif
-        // New style AMDAR
-        add_testcodec("gts-amdar1.bufr", [](TestCodec& test) {
-            // FIXME: currently fails
-            wassert(test.run_reimport());
-            wassert(test.run_convert("amdar-wmo"));
-        });
-        add_testcodec("gts-amdar2.bufr", [](TestCodec& test) {
-            // FIXME: currently fails
-            wassert(test.run_reimport());
-            wassert(test.run_convert("amdar-wmo"));
-        });
         // Re-export to BUFR (simplified, full template autodetect) and see the differences
         add_method("all_simplified", []() {
             const char** files = dballe::tests::bufr_files;
@@ -631,14 +615,6 @@ class Tests : public TestCase
             wassert(test.run_convert("pilot-wmo"));
         });
         // New style PILOT
-        add_testcodec("pilot-gts1.bufr", [](TestCodec& test) {
-            test.expected_data_category = 2;
-            test.expected_data_subcategory = 1;
-            test.expected_data_subcategory_local = 211;
-
-            wassert(test.run_reimport());
-            wassert(test.run_convert("pilot-wmo"));
-        });
         add_testcodec("pilot-ecmwf-geopotential.bufr", [](TestCodec& test) {
             test.configure_ecmwf_to_wmo_tweaks();
             test.after_reimport_reimport.add(new StripVars({ WR_VAR(0, 10, 8) }));
@@ -751,6 +727,19 @@ class Tests : public TestCase
             wassert(test.run_reimport());
             wassert(test.run_convert("acars"));
         });
+        // // Soil temperatures (we still do not have a template to export this)
+        // add_testcodec("test-soil1.bufr", [](TestCodec& test) {
+        //     test.expected_min_vars = 10;
+
+        //     wassert(test.run_reimport());
+        // });
+        // Specific issues
+        add_testcodec("issue62.bufr", [](TestCodec& test) {
+            test.expected_min_vars = 21;
+
+            wassert(test.run_reimport());
+            wassert(test.run_convert("temp-wmo"));
+        });
     }
 } test("msg_wr_export");
 
