@@ -40,7 +40,7 @@ class Tests : public TestCase
 
     void add_bufr_method(const std::string& fname, std::function<void(const Messages& msgs)> m)
     {
-        add_method(fname, [=]() {
+        add_method("prec_" + fname, [=]() {
             std::string pathname = "bufr/" + fname;
             msg::Importer::Options opts;
             opts.simplified = false;
@@ -51,7 +51,7 @@ class Tests : public TestCase
 
     void add_bufr_simplified_method(const std::string& fname, std::function<void(const Messages& msgs)> m)
     {
-        add_method(fname, [=]() {
+        add_method("simp_" + fname, [=]() {
             std::string pathname = "bufr/" + fname;
             msg::Importer::Options opts;
             opts.simplified = true;
@@ -322,22 +322,6 @@ class Tests : public TestCase
             IS(ident, "FJCYR4RA");
         });
 
-        // WMO AMDAR
-        add_bufr_simplified_method("gts-amdar1.bufr", [](const Messages& msgs) {
-            wassert(actual(msgs.size()) == 1u);
-            const Msg& msg = Msg::downcast(msgs[0]);
-            wassert(actual(msg.type) == MSG_AMDAR);
-            IS(ident, "EU0274");
-        });
-
-        // WMO AMDAR
-        add_bufr_simplified_method("gts-amdar2.bufr", [](const Messages& msgs) {
-            wassert(actual(msgs.size()) == 1u);
-            const Msg& msg = Msg::downcast(msgs[0]);
-            wassert(actual(msg.type) == MSG_AMDAR);
-            IS(ident, "EU7866");
-        });
-
         // BUFR that has a variable that goes out of range when converted to local B
         // table
         add_method("outofrange", []() {
@@ -362,13 +346,6 @@ class Tests : public TestCase
             }
         });
 
-        // WMO PILOT, with geopotential levels
-        add_bufr_simplified_method("pilot-gts1.bufr", [](const Messages& msgs) {
-            wassert(actual(msgs.size()) == 1u);
-            const Msg& msg = Msg::downcast(msgs[0]);
-            wassert(actual(msg.type) == MSG_PILOT);
-        });
-
         // WMO PILOT, with pressure levels
         add_bufr_simplified_method("pilot-gts2.bufr", [](const Messages& msgs) {
             wassert(actual(msgs.size()) == 1u);
@@ -419,6 +396,19 @@ class Tests : public TestCase
             wassert(actual(v).istrue());
             wassert(actual(v->enqd()) == 284.75);
         });
+
+        // Soil temperature (see https://github.com/ARPA-SIMC/dballe/issues/41 )
+        add_bufr_simplified_method("test-soil1.bufr", [](const Messages& msgs) {
+            wassert(actual(msgs.size()) == 1u);
+            const Msg& msg = Msg::downcast(msgs[0]);
+            wassert(actual(msg.type) == MSG_SYNOP);
+            IS2(WR_VAR(0, 12, 30), Level(106,   50), Trange::instant(), 288.5);
+            IS2(WR_VAR(0, 12, 30), Level(106,  100), Trange::instant(), 289.4);
+            IS2(WR_VAR(0, 12, 30), Level(106,  200), Trange::instant(), 288.6);
+            IS2(WR_VAR(0, 12, 30), Level(106,  500), Trange::instant(), 288.8);
+            IS2(WR_VAR(0, 12, 30), Level(106, 1000), Trange::instant(), 288.4);
+        });
+
     }
 } test("msg_wr_import");
 
