@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005--2014  ARPA-SIM <urpsim@smr.arpa.emr.it>
+ * Copyright (C) 2005--2015  ARPA-SIM <urpsim@smr.arpa.emr.it>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  */
 
 #include "base.h"
-#include <dballe/core/var.h>
+#include "dballe/core/var.h"
 #include <wreport/bulletin.h>
 #include <wreport/subset.h>
 #include <wreport/conv.h>
@@ -37,35 +37,44 @@ protected:
     Level lev;
     Trange tr;
 
+    /// Import an undefined value
+    void import_defined(const Var& var);
+    /// Import a defined value, which can be a variable or context
+    void import_undef(const Var& var);
+    /// Import a defined value, with the context being properly set
     void import_var(const Var& var);
-    void import_var_undef(const Var& var);
 
 public:
     GenericImporter(const msg::Importer::Options& opts) : Importer(opts) {}
     virtual ~GenericImporter() {}
 
-    virtual void init()
+    void init() override
     {
         Importer::init();
         lev = Level();
         tr = Trange();
     }
 
-    virtual void run()
+    void run() override
     {
         for (size_t pos = 0; pos < subset->size(); ++pos)
         {
                 const Var& var = (*subset)[pos];
+                // Skip non-variable entries
                 if (WR_VAR_F(var.code()) != 0) continue;
-                if (var.value() == NULL)
+                // Special processing for undefined variables
+                if (!var.isset())
                 {
-                    /* Also skip attributes if there are some following */
+                    // Also skip attributes of undefined variables if there are
+                    // some following
                     for ( ; pos + 1 < subset->size() &&
                             WR_VAR_X((*subset)[pos + 1].code()) == 33; ++pos)
                         ;
-                    import_var_undef(var);
+                    import_undef(var);
                     continue;
                 }
+                // A variable with a value: add attributes to it if any are
+                // found
                 if (pos + 1 < subset->size() &&
                         WR_VAR_X((*subset)[pos + 1].code()) == 33)
                 {
@@ -73,24 +82,24 @@ public:
                     for ( ; pos + 1 < subset->size() &&
                             WR_VAR_X((*subset)[pos + 1].code()) == 33; ++pos)
                         copy.seta((*subset)[pos + 1]);
-                    import_var(copy);
+                    import_defined(copy);
                 } else
-                    import_var(var);
+                    import_defined(var);
         }
     }
 
-    MsgType scanType(const Bulletin&) const
+    MsgType scanType(const Bulletin&) const override
     {
         return MSG_GENERIC;
     }
 };
 
-std::auto_ptr<Importer> Importer::createGeneric(const msg::Importer::Options& opts)
+std::unique_ptr<Importer> Importer::createGeneric(const msg::Importer::Options& opts)
 {
-    return auto_ptr<Importer>(new GenericImporter(opts));
+    return unique_ptr<Importer>(new GenericImporter(opts));
 }
 
-void GenericImporter::import_var_undef(const Var& var)
+void GenericImporter::import_undef(const Var& var)
 {
     switch (var.code())
     {
@@ -104,7 +113,7 @@ void GenericImporter::import_var_undef(const Var& var)
     }
 }
 
-void GenericImporter::import_var(const Var& var)
+void GenericImporter::import_defined(const Var& var)
 {
     switch (var.code())
     {
@@ -116,29 +125,52 @@ void GenericImporter::import_var(const Var& var)
         case WR_VAR(0, 7, 194): lev.l2 = var.enqi(); break;
         case WR_VAR(0, 7, 195): lev.ltype2 = var.enqi(); break;
         case WR_VAR(0, 1, 194):
-            // Set the rep memo if we found it
-            msg->type = Msg::type_from_repmemo(var.value());
-            msg->set_rep_memo(var.value(), -1);
+            if (var.isset())
+            {
+                // Set the rep memo if we found it
+                const char* repmemo = var.enqc();
+                msg->type = Msg::type_from_repmemo(repmemo);
+                msg->set_rep_memo(repmemo, -1);
+            }
             break;
-        // Legacy variable conversions
-        case WR_VAR(0, 8, 1): {
-            auto_ptr<Var> nvar(newvar(WR_VAR(0, 8, 42), convert_BUFR08001_to_BUFR08042(var.enqi())));
-            nvar->copy_attrs(var);
-            msg->set(nvar, lev, tr);
-            break;
-        }
         default:
-            // Adjust station info level for pre-dballe-5.0 generics
-            if (lev.ltype1 == 257)
-                msg->set(var, map_code_to_dballe(var.code()), Level::ana(), Trange());
-            else
-                msg->set(var, map_code_to_dballe(var.code()), lev, tr);
+            import_var(var);
             break;
     }
 }
 
-} // namespace wbimporter
-} // namespace msg
-} // namespace dballe
+void GenericImporter::import_var(const Var& var)
+{
+    // Adjust station info level for pre-dballe-5.0 generics
+    if (lev.ltype1 == 257)
+    {
+        lev = Level();
+        tr = Trange();
+    }
 
-/* vim:set ts=4 sw=4: */
+    switch (var.code())
+    {
+        // Legacy variable conversions
+        case WR_VAR(0, 8, 1): {
+            unique_ptr<Var> nvar(newvar(WR_VAR(0, 8, 42), (int)convert_BUFR08001_to_BUFR08042(var.enqi())));
+            nvar->setattrs(var);
+            msg->set(move(nvar), lev, tr);
+            break;
+        }
+        // Datetime entries that may have attributes to store
+        case WR_VAR(0,  4,  1): ye = var.enqi(); if (var.next_attr()) msg->set_year_var(var); break;
+        case WR_VAR(0,  4,  2): mo = var.enqi(); if (var.next_attr()) msg->set_month_var(var); break;
+        case WR_VAR(0,  4,  3): da = var.enqi(); if (var.next_attr()) msg->set_day_var(var); break;
+        case WR_VAR(0,  4,  4): ho = var.enqi(); if (var.next_attr()) msg->set_hour_var(var); break;
+        case WR_VAR(0,  4,  5): mi = var.enqi(); if (var.next_attr()) msg->set_minute_var(var); break;
+        case WR_VAR(0,  4,  6): se = var.enqi(); if (var.next_attr()) msg->set_second_var(var); break;
+        // Anything else
+        default:
+            msg->set(var, map_code_to_dballe(var.code()), lev, tr);
+            break;
+    }
+}
+
+}
+}
+}
