@@ -1,22 +1,3 @@
-/*
- * Copyright (C) 2005--2011  ARPA-SIM <urpsim@smr.arpa.emr.it>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
- *
- * Author: Enrico Zini <enrico@enricozini.com>
- */
-
 #include "base.h"
 #include <wreport/bulletin.h>
 #include <wreport/subset.h>
@@ -46,7 +27,7 @@ protected:
         else if (opts.simplified)
         {
             Var var1(var);
-            var1.seta(auto_ptr<Var>(newvar(WR_VAR(0, 7, 32), height_sensor).release()));
+            var1.seta(newvar(WR_VAR(0, 7, 32), height_sensor));
             msg->set(var1, code, defaultLevel, trange);
         } else
             msg->set(var, code, Level(103, height_sensor * 1000), trange);
@@ -123,8 +104,6 @@ void MetarImporter::import_var(const Var& var)
     }
 }
 
-} // namespace wbimporter
-} // namespace msg
-} // namespace dballe
-
-/* vim:set ts=4 sw=4: */
+}
+}
+}
