@@ -1,22 +1,3 @@
-/*
- * Copyright (C) 2005--2013  ARPA-SIM <urpsim@smr.arpa.emr.it>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
- *
- * Author: Enrico Zini <enrico@enricozini.com>
- */
-
 #include "base.h"
 #include <wreport/bulletin.h>
 #include <wreport/subset.h>
@@ -91,7 +72,12 @@ void ShipImporter::import_var(const Var& var)
         case WR_VAR(0,  2, 38): msg->set(var, var.code(), Level(), Trange()); break;
         case WR_VAR(0,  2, 39): msg->set(var, var.code(), Level(), Trange()); break;
         case WR_VAR(0, 22, 42):
-        case WR_VAR(0, 22, 43): ctx.set_water_temperature(var); break;
+        case WR_VAR(0, 22, 43):
+            if (level.sea_depth == LevelContext::missing)
+                set(var, WR_VAR(0, 22, 43), Level(1), Trange::instant());
+            else
+                set(var, WR_VAR(0, 22, 43), Level(160, level.sea_depth * 1000), Trange::instant());
+            break;
 
         // Waves
         case WR_VAR(0, 22,  1):
@@ -106,7 +92,7 @@ void ShipImporter::import_var(const Var& var)
         case WR_VAR(0, 22,  3): // Direction of swell waves
         case WR_VAR(0, 22, 13): // Period of swell waves
         case WR_VAR(0, 22, 23): // Height of swell waves
-            ctx.set_swell_waves(var);
+            set(var, var.code(), Level(264, MISSING_INT, 261, level.swell_wave_group), Trange::instant());
             break;
 
         default: SynopBaseImporter::import_var(var); break;
@@ -121,8 +107,6 @@ std::unique_ptr<Importer> Importer::createShip(const msg::Importer::Options& opt
 }
 
 
-} // namespace wbimporter
-} // namespace msg
-} // namespace dballe
-
-/* vim:set ts=4 sw=4: */
+}
+}
+}
