@@ -817,6 +817,45 @@ add_method("issue52", [](Fixture& f) {
     // error: no year information found in message to import
 });
 
+add_method("issue73", [](Fixture& f) {
+    using namespace wreport;
+
+    {
+        fortran::DbAPI dbapi(*f.db, "write", "write", "write");
+        populate_variables(dbapi);
+    }
+
+    {
+        fortran::DbAPI dbapi(*f.db, "read", "read", "read");
+        dbapi.setc("varlist", "B10004,B12101,B12103");
+        wassert(actual(dbapi.voglioquesto()) == 1);
+    }
+});
+
+add_method("issue75", [](Fixture& f) {
+    using namespace wreport;
+
+    std::string fname = dballe::tests::datafile("bufr/issue75.bufr");
+    {
+        fortran::DbAPI dbapi(*f.db, "write", "write", "write");
+        wassert(dbapi.messages_open_input(fname.c_str(), "r", File::BUFR, true));
+        wassert(actual(dbapi.messages_read_next()).istrue());
+        wassert(actual(dbapi.messages_read_next()).istrue());
+        wassert(actual(dbapi.messages_read_next()).istrue());
+        wassert(actual(dbapi.messages_read_next()).istrue());
+    }
+
+    {
+        fortran::DbAPI dbapi(*f.db, "read", "read", "read");
+        dbapi.setc("rep_memo", "temp");
+        dbapi.setcontextana();
+        dbapi.setc("varlist", "B07001");
+        wassert(actual(dbapi.voglioquesto()) == 0);
+        dbapi.setc("varlist", "B07030");
+        wassert(actual(dbapi.voglioquesto()) == 1);
+    }
+});
+
 }
 
 }
