@@ -29,7 +29,7 @@ namespace dballe {
 namespace fortran {
 
 const signed char API::missing_byte = numeric_limits<signed char>::max();
-const int API::missing_int = numeric_limits<int>::max();
+const int API::missing_int = MISSING_INT;
 const float API::missing_float = numeric_limits<float>::max();
 const double API::missing_double = numeric_limits<double>::max();
 
