@@ -1,4 +1,5 @@
 #include "types.h"
+#include "core/csv.h"
 #include <wreport/error.h>
 #include <ostream>
 #include <iomanip>
@@ -162,6 +163,19 @@ void Date::to_stream_iso8601(std::ostream& out) const
         << '-' << setw(2) << setfill('0') << (unsigned)day;
 }
 
+void Date::to_csv_iso8601(CSVWriter& out) const
+{
+    if (is_missing())
+        out.add_value_empty();
+    else
+    {
+        char buf[16];
+        snprintf(buf, 16, "%04hu-%02hhu-%02hhu", year, month, day);
+        out.add_value(buf);
+    }
+}
+
+
 
 /*
  * Time
@@ -240,6 +254,18 @@ void Time::to_stream_iso8601(std::ostream& out) const
         << ':' << setw(2) << setfill('0') << (unsigned)second;
 }
 
+void Time::to_csv_iso8601(CSVWriter& out) const
+{
+    if (is_missing())
+        out.add_value_empty();
+    else
+    {
+        char buf[16];
+        snprintf(buf, 16, "%02hhu:%02hhu:%02hhu", hour, minute, second);
+        out.add_value(buf);
+    }
+}
+
 /*
  * Datetime
  */
@@ -378,12 +404,25 @@ void Datetime::to_stream_iso8601(std::ostream& out, char sep, const char* tz) co
         << tz;
 }
 
-void Datetime::print_iso8601(FILE* out, char sep, const char* end) const
+int Datetime::print_iso8601(FILE* out, char sep, const char* end) const
 {
-    fprintf(out, "%04hu-%02hhu-%02hhu%c%02hhu:%02hhu:%02hhu%s",
+    return fprintf(out, "%04hu-%02hhu-%02hhu%c%02hhu:%02hhu:%02hhu%s",
             year, month, day, sep, hour, minute, second, end);
 }
 
+void Datetime::to_csv_iso8601(CSVWriter& out, char sep, const char* tz) const
+{
+    if (is_missing())
+        out.add_value_empty();
+    else
+    {
+        char buf[32];
+        snprintf(buf, 32, "%04hu-%02hhu-%02hhu%c%02hhu:%02hhu:%02hhu%s",
+                year, month, day, sep, hour, minute, second, tz);
+        out.add_value(buf);
+    }
+}
+
 /*
  * DatetimeRange
  */
@@ -549,9 +588,9 @@ bool Coords::operator>(const Coords& o) const { return compare(o) > 0; }
 bool Coords::operator<=(const Coords& o) const { return compare(o) <= 0; }
 bool Coords::operator>=(const Coords& o) const { return compare(o) >= 0; }
 
-void Coords::print(FILE* out, const char* end) const
+int Coords::print(FILE* out, const char* end) const
 {
-    fprintf(out, "%.5f,%.5f%s", dlat(), dlon(), end);
+    return fprintf(out, "%.5f,%.5f%s", dlat(), dlon(), end);
 }
 
 /*
@@ -764,21 +803,10 @@ bool Level::operator!=(const Level& l) const
 bool Level::operator<(const Level& l) const { return compare(l) < 0; }
 bool Level::operator>(const Level& l) const { return compare(l) > 0; }
 
-namespace {
-std::string fmtf( const char* f, ... )
-{
-    char *c;
-    va_list ap;
-    va_start( ap, f );
-    vasprintf( &c, f, ap );
-    std::string ret( c );
-    free( c );
-    return ret;
-}
-}
-
 static std::string describe_level(int ltype, int val)
 {
+    char buf[256];
+
     switch (ltype)
     {
         case 1:   return "Ground or water surface";
@@ -789,24 +817,24 @@ static std::string describe_level(int ltype, int val)
         case 6:   return "Maximum wind level";
         case 7:   return "Tropopause";
         case 8:   if (val == 0)
-                  return "Nominal top of atmosphere";
-              else
-                  return fmtf("Nominal top of atmosphere, channel %d", val);
+                      return "Nominal top of atmosphere";
+                  else
+                      return snprintf(buf, 256, "Nominal top of atmosphere, channel %d", val), buf;
         case 9:   return "Sea bottom";
-        case 20:  return fmtf("Isothermal level, %.1fK", (double)val/10);
-        case 100: return fmtf("Isobaric surface, %.2fhPa", (double)val/100);
+        case 20:  return snprintf(buf, 256, "Isothermal level, %.1fK", (double)val/10), buf;
+        case 100: return snprintf(buf, 256, "Isobaric surface, %.2fhPa", (double)val/100), buf;
         case 101: return "Mean sea level";
-        case 102: return fmtf("%.3fm above mean sea level", (double)val/1000);
-        case 103: return fmtf("%.3fm above ground", (double)val/1000);
-        case 104: return fmtf("Sigma level %.5f", (double)val/10000);
-        case 105: return fmtf("Hybrid level %d", val);
-        case 106: return fmtf("%.3fm below land surface", (double)val/1000);
-        case 107: return fmtf("Isentropic (theta) level, potential temperature %.1fK", (double)val/10);
-        case 108: return fmtf("Pressure difference %.2fhPa from ground to level", (double)val/100);
-        case 109: return fmtf("Potential vorticity surface %.3f 10-6 K m2 kg-1 s-1", (double)val/1000);
-        case 111: return fmtf("ETA* level %.5f", (double)val/10000);
-        case 117: return fmtf("Mixed layer depth %.3fm", (double)val/1000);
-        case 160: return fmtf("%.3fm below sea level", (double)val/1000);
+        case 102: return snprintf(buf, 256, "%.3fm above mean sea level", (double)val/1000), buf;
+        case 103: return snprintf(buf, 256, "%.3fm above ground", (double)val/1000), buf;
+        case 104: return snprintf(buf, 256, "Sigma level %.5f", (double)val/10000), buf;
+        case 105: return snprintf(buf, 256, "Hybrid level %d", val), buf;
+        case 106: return snprintf(buf, 256, "%.3fm below land surface", (double)val/1000), buf;
+        case 107: return snprintf(buf, 256, "Isentropic (theta) level, potential temperature %.1fK", (double)val/10), buf;
+        case 108: return snprintf(buf, 256, "Pressure difference %.2fhPa from ground to level", (double)val/100), buf;
+        case 109: return snprintf(buf, 256, "Potential vorticity surface %.3f 10-6 K m2 kg-1 s-1", (double)val/1000), buf;
+        case 111: return snprintf(buf, 256, "ETA* level %.5f", (double)val/10000), buf;
+        case 117: return snprintf(buf, 256, "Mixed layer depth %.3fm", (double)val/1000), buf;
+        case 160: return snprintf(buf, 256, "%.3fm below sea level", (double)val/1000), buf;
         case 200: return "Entire atmosphere (considered as a single layer)";
         case 201: return "Entire ocean (considered as a single layer)";
         case 204: return "Highest tropospheric freezing level";
@@ -826,7 +854,7 @@ static std::string describe_level(int ltype, int val)
         case 232: return "High cloud bottom level";
         case 233: return "High cloud top level";
         case 234: return "High cloud layer";
-        case 235: return fmtf("Ocean Isotherm Level, %.1fK", (double)val/10); break;
+        case 235: return snprintf(buf, 256, "Ocean Isotherm Level, %.1fK", (double)val/10), buf;
         case 240: return "Ocean Mixed Layer";
         case 242: return "Convective cloud bottom level";
         case 243: return "Convective cloud top level";
@@ -848,15 +876,15 @@ static std::string describe_level(int ltype, int val)
                 case 1: return "CL";
                 case 2: return "CM";
                 case 3: return "CH";
-                default: return fmtf("%d %d", ltype, val);
+                default: return snprintf(buf, 256, "%d %d", ltype, val), buf;
             }
             break;
-        case 259: return fmtf("Cloud group %d", val);
-        case 260: return fmtf("Cloud drift group %d", val);
-        case 261: return fmtf("Cloud elevation group %d", val);
+        case 259: return snprintf(buf, 256, "Cloud group %d", val), buf;
+        case 260: return snprintf(buf, 256, "Cloud drift group %d", val), buf;
+        case 261: return snprintf(buf, 256, "Cloud elevation group %d", val), buf;
         case 262: return "Direction and elevation of clouds";
         case MISSING_INT: return "Information about the station that generated the data";
-        default:    return fmtf("%d %d", ltype, val); break;
+        default:    return snprintf(buf, 256, "%d %d", ltype, val), buf; break;
     }
 }
 
@@ -888,27 +916,37 @@ void Level::to_stream(std::ostream& out, const char* undef) const
     if (l2 == MISSING_INT) out << undef; else out << l2;
 }
 
+void Level::to_csv(CSVWriter& out) const
+{
+    if (ltype1 == MISSING_INT) out.add_value_empty(); else out.add_value(ltype1);
+    if (l1 == MISSING_INT) out.add_value_empty(); else out.add_value(l1);
+    if (ltype2 == MISSING_INT) out.add_value_empty(); else out.add_value(ltype2);
+    if (l2 == MISSING_INT) out.add_value_empty(); else out.add_value(l2);
+}
+
 Level Level::cloud(int ltype2, int l2) { return Level(256, MISSING_INT, ltype2, l2); }
 
-void Level::print(FILE* out, const char* undef, const char* end) const
+int Level::print(FILE* out, const char* undef, const char* end) const
 {
+    int res = 0;
     if (ltype1 == MISSING_INT)
-        fprintf(out, "%s,", undef);
+        res += fprintf(out, "%s,", undef);
     else
-        fprintf(out, "%d,", ltype1);
+        res += fprintf(out, "%d,", ltype1);
     if (l1 == MISSING_INT)
-        fprintf(out, "%s,", undef);
+        res += fprintf(out, "%s,", undef);
     else
-        fprintf(out, "%d,", l1);
+        res += fprintf(out, "%d,", l1);
     if (ltype2 == MISSING_INT)
-        fprintf(out, "%s,", undef);
+        res += fprintf(out, "%s,", undef);
     else
-        fprintf(out, "%d,", ltype2);
+        res += fprintf(out, "%d,", ltype2);
     if (l2 == MISSING_INT)
-        fprintf(out, "%s,", undef);
+        res += fprintf(out, "%s,", undef);
     else
-        fprintf(out, "%d,", l2);
-    fputs(end, out);
+        res += fprintf(out, "%d", l2);
+    res += fprintf(out, "%s", end);
+    return res;
 }
 
 
@@ -948,6 +986,13 @@ void Trange::to_stream(std::ostream& out, const char* undef) const
     if (p2 == MISSING_INT) out << undef; else out << p2;
 }
 
+void Trange::to_csv(CSVWriter& out) const
+{
+    if (pind == MISSING_INT) out.add_value_empty(); else out.add_value(pind);
+    if (p1 == MISSING_INT) out.add_value_empty(); else out.add_value(p1);
+    if (p2 == MISSING_INT) out.add_value_empty(); else out.add_value(p2);
+}
+
 Trange Trange::instant() { return Trange(254, 0, 0); }
 
 static std::string format_seconds(int val)
@@ -1005,6 +1050,8 @@ static std::string mkdesc(const std::string& root, int p1, int p2)
 
 std::string Trange::describe() const
 {
+    char buf[256];
+
     switch (pind)
     {
         case 0:   return mkdesc("Average", p1, p2);
@@ -1029,24 +1076,27 @@ std::string Trange::describe() const
                   return "Analysis or observation, istantaneous value";
               else
                   return "Forecast at t+" + format_seconds(p1) + ", instantaneous value";
-        default:  return fmtf("%d %d %d", pind, p1, p2);
+        default:  return snprintf(buf, 256, "%d %d %d", pind, p1, p2), buf;
     }
 }
 
-void Trange::print(FILE* out, const char* undef, const char* end) const
+int Trange::print(FILE* out, const char* undef, const char* end) const
 {
+    int res = 0;
     if (pind == MISSING_INT)
-        fprintf(out, "%s,", undef);
+        res += fprintf(out, "%s,", undef);
     else
-        fprintf(out, "%d,", pind);
+        res += fprintf(out, "%d,", pind);
     if (p1 == MISSING_INT)
-        fprintf(out, "%s,", undef);
+        res += fprintf(out, "%s,", undef);
     else
-        fprintf(out, "%d,", p1);
+        res += fprintf(out, "%d,", p1);
     if (p2 == MISSING_INT)
-        fprintf(out, "%s,", undef);
+        res += fprintf(out, "%s,", undef);
     else
-        fprintf(out, "%d,", p2);
+        res += fprintf(out, "%d", p2);
+    res += fprintf(out, "%s", end);
+    return res;
 }
 
 }
