@@ -9,6 +9,7 @@
 #include <limits.h>
 
 namespace dballe {
+struct CSVWriter;
 
 /**
  * Value to use for missing parts of level and time range values
@@ -55,6 +56,11 @@ struct Date
      */
     void to_stream_iso8601(std::ostream& out) const;
 
+    /**
+     * Write the date as a CSV field in ISO8601 date format.
+     */
+    void to_csv_iso8601(CSVWriter& out) const;
+
     /**
      * Generic comparison
      *
@@ -114,6 +120,11 @@ struct Time
      */
     void to_stream_iso8601(std::ostream& out) const;
 
+    /**
+     * Write the time as a CSV field in ISO8601 date format.
+     */
+    void to_csv_iso8601(CSVWriter& out) const;
+
     /**
      * Generic comparison
      *
@@ -211,16 +222,22 @@ struct Datetime
     /**
      * Print to an output stream in ISO8601 combined format.
      */
-    void print_iso8601(FILE* out, char sep='T', const char* end="\n") const;
+    int print_iso8601(FILE* out, char sep='T', const char* end="\n") const;
 
     /**
      * Write the datetime to an output stream in ISO8601 combined format.
      *
+     * @param out the output stream
      * @param sep the separator character between date and time
      * @param tz the timezone string to use at the end of the datetime
      */
     void to_stream_iso8601(std::ostream& out, char sep='T', const char* tz="") const;
 
+    /**
+     * Write the datetime as a CSV field in ISO8601 date format.
+     */
+    void to_csv_iso8601(CSVWriter& out, char sep='T', const char* tz="") const;
+
     /**
      * Parse an ISO8601 datetime string.
      *
@@ -370,7 +387,7 @@ struct Coords
     bool operator>=(const Coords& dt) const;
 
     /// Print to an output stream
-    void print(FILE* out, const char* end="\n") const;
+    int print(FILE* out, const char* end="\n") const;
 };
 
 
@@ -551,11 +568,16 @@ struct Level
     /// Format to an output stream
     void to_stream(std::ostream& out, const char* undef="-") const;
 
+    /**
+     * Write the datetime to a CSV writer as 4 fields
+     */
+    void to_csv(CSVWriter& out) const;
+
     /// Create a cloud special level. See @ref level_table.
     static Level cloud(int ltype2=MISSING_INT, int l2=MISSING_INT);
 
     /// Print to an output stream
-    void print(FILE* out, const char* undef="-", const char* end="\n") const;
+    int print(FILE* out, const char* undef="-", const char* end="\n") const;
 };
 
 
@@ -564,11 +586,11 @@ struct Level
  */
 struct Trange
 {
-    /// Time range type indicator.  See @ref trange_table.
+    /// Time range type indicator.
     int pind;
-    /// Time range P1 indicator.  See @ref trange_table.
+    /// Time range P1 indicator.
     int p1;
-    /// Time range P2 indicator.  See @ref trange_table.
+    /// Time range P2 indicator.
     int p2;
 
     Trange(int pind=MISSING_INT, int p1=MISSING_INT, int p2=MISSING_INT)
@@ -599,11 +621,16 @@ struct Trange
     /// Format to an output stream
     void to_stream(std::ostream& out, const char* undef="-") const;
 
+    /**
+     * Write the datetime to a CSV writer as 3 fields
+     */
+    void to_csv(CSVWriter& out) const;
+
     /// Time range for instant values
     static Trange instant();
 
     /// Print to an output stream
-    void print(FILE* out, const char* undef="-", const char* end="\n") const;
+    int print(FILE* out, const char* undef="-", const char* end="\n") const;
 };
 
 
