@@ -19,7 +19,15 @@ class Tests : public TestCase
             wassert(actual(resolve_varcode("t")) == WR_VAR(0, 12, 101));
             try {
                 resolve_varcode("B121");
-                throw TestFailed("an exception should be thrown");
+                wassert(throw TestFailed("an exception should be thrown"));
+            } catch (TestFailed) {
+                throw;
+            } catch (std::exception& e) {
+                wassert(actual(e.what()).contains("cannot parse"));
+            }
+            try {
+                resolve_varcode("B1210A");
+                wassert(throw TestFailed("an exception should be thrown"));
             } catch (TestFailed) {
                 throw;
             } catch (std::exception& e) {
