@@ -5,8 +5,7 @@ program check_range
 ! *****************************************
 
       use dbtest
-
-      include "dballef.h" 
+      use dballef
       
       integer :: handle,idbhandle,handle_err, errcode
       real :: rval
@@ -20,29 +19,29 @@ program check_range
       call dbinit(idbhandle)
 
 !     Open a session
-      call idba_preparati(idbhandle,handle,"write","write","write")
+      ierr = idba_preparati(idbhandle,handle,"write","write","write")
       call ensure_no_error("preparati")
 
 !     Check that NaN values are trapped
       rval = 0.
       rval = log(rval) / log(rval)
-      call idba_set(handle, "B12103", log(rval))
+      ierr = idba_set(handle, "B12103", log(rval))
       errcode = idba_error_code()
       call ensure("set to NaN", errcode == 13)
 
 !     Check that negative reals can be read
-      call idba_set(handle, "lon", -12.3456)
+      ierr = idba_set(handle, "lon", -12.3456)
       call ensure_no_error("set lon negative")
-      call idba_test_input_to_output(handle)
+      ierr = idba_test_input_to_output(handle)
       call ensure_no_error("input to output")
-      call idba_enqr(handle, "lon", rval)
+      ierr = idba_enqr(handle, "lon", rval)
       call ensure_no_error("enq lon negative")
       call ensure("read negative real", rval == -12.3456)
 
-      call idba_fatto(handle)
+      ierr = idba_fatto(handle)
       call ensure_no_error("fatto")
 
-      call idba_arrivederci(idbhandle)
+      ierr = idba_arrivederci(idbhandle)
       call ensure_no_error("arrivederci")
   
       call exit (0)
