@@ -1,11 +1,12 @@
       module dbtest
 
       use test
+      use dballef
 
       contains
 
       subroutine dbinit(dbahandle)
-      integer::dbahandle, handle
+      integer::dbahandle, handle, ierr
       character (len=160) :: dsn,testname
         call getenv("DBA_DB", dsn)
         call getarg(0, testname)
@@ -14,12 +15,12 @@
           dsn = "test:"
         end if
 
-        call idba_presentati(dbahandle, dsn, char(0), char(0))
+        ierr = idba_presentati(dbahandle, dsn)
         call ensure_no_error("presentati")
 
-        call idba_preparati(dbahandle, handle, "write", "write", "write")
-        call idba_scopa(handle, char(0))
-        call idba_fatto(handle)
+        ierr = idba_preparati(dbahandle, handle, "write", "write", "write")
+        ierr = idba_scopa(handle, char(0))
+        ierr = idba_fatto(handle)
       endsubroutine dbinit
 
       endmodule dbtest
