@@ -1,67 +1,68 @@
       program dump_dballe
+      use dballef
 
 ! *****************************************
 ! * Dump the contents of a dballe database
 ! *****************************************
 
       integer dbahandle, handle, handle_ana, nstaz, ndata, nattr
-      integer i, i1, i2, tmp
+      integer i, i1, i2, tmp, ierr
       integer id,height
       character cname*20,rete*20,value*255,avalue*255
       character btable*10,starbtable*10
       real dlat,dlon
       external errorrep
 
-      call idba_error_set_callback(0, errorrep, 2, i)
+      ierr = idba_error_set_callback(0, C_FUNLOC(errorrep), 2, i)
 
 !     Database login
-      call idba_presentati(dbahandle, "test", "enrico", "")
+      ierr = idba_presentati(dbahandle, "test")
 
 !     Open a session
-      call idba_preparati(dbahandle, handle_ana, "read", "read", "read")
-      call idba_preparati(dbahandle, handle, "read", "read", "read")
+      ierr = idba_preparati(dbahandle, handle_ana, "read", "read", "read")
+      ierr = idba_preparati(dbahandle, handle, "read", "read", "read")
 
 !     Query all the stations
-      call idba_quantesono(handle_ana, nstaz)
+      ierr = idba_quantesono(handle_ana, nstaz)
       write (*,*) nstaz," stazioni:"
 
       do i=1, nstaz
-        call idba_elencamele(handle_ana)
-        call idba_enqc(handle_ana, "name", cname)
-        call idba_enqi(handle_ana, "ana_id", id)
-        call idba_enqr(handle_ana, "lat", dlat)
-        call idba_enqr(handle_ana, "lon", dlon)
-        call idba_enqi(handle_ana, "height", height)
-        call idba_enqc(handle_ana,"rep_memo",rete)
+        ierr = idba_elencamele(handle_ana)
+        ierr = idba_enqc(handle_ana, "name", cname)
+        ierr = idba_enqi(handle_ana, "ana_id", id)
+        ierr = idba_enqr(handle_ana, "lat", dlat)
+        ierr = idba_enqr(handle_ana, "lon", dlon)
+        ierr = idba_enqi(handle_ana, "height", height)
+        ierr = idba_enqc(handle_ana,"rep_memo",rete)
         write (*,*) "Staz ",id," (",dlat,",",dlon,") '", &
             cname(:istrlen(cname)),"' h:",height, &
             " ",rep_memo
-        call idba_seti(handle,"ana_id",id)
-        call idba_voglioquesto(handle,ndata)
+        ierr = idba_seti(handle,"ana_id",id)
+        ierr = idba_voglioquesto(handle,ndata)
         write (*,*) " ",ndata," dati:"
         do i1=1, ndata
-          call idba_dammelo(handle,btable)
-          call idba_enqc(handle,btable,value)
+          ierr = idba_dammelo(handle,btable)
+          ierr = idba_enqc(handle,btable,value)
           write (*,*) '  var ',btable(:istrlen(btable)),": ", &
-            value(:istrlen(btable))
+            value(:istrlen(value))
 
-          call idba_enqi(handle,"!context_id",tmp)
+          ierr = idba_enqi(handle,"!context_id",tmp)
           write (*,*) "  CTX: ",tmp
 
-          call idba_voglioancora (handle,nattr)
+          ierr = idba_voglioancora (handle,nattr)
           write (*,*) "   ",nattr," attributi:"
           do i2=1, nattr
-            call idba_ancora(handle,starbtable)
-            call idba_enqc(handle,starbtable,avalue)
+            ierr = idba_ancora(handle,starbtable)
+            ierr = idba_enqc(handle,starbtable,avalue)
             write(*,*) "    attr ",starbtable(:istrlen(starbtable)), &
               ": ",avalue(:istrlen(avalue))
           enddo
         enddo
       enddo
 
-      call idba_fatto(handle_ana)
-      call idba_fatto(handle)
-      call idba_arrivederci(dbahandle)
+      ierr = idba_fatto(handle_ana)
+      ierr = idba_fatto(handle)
+      ierr = idba_arrivederci(dbahandle)
 
       call exit (0)
     
@@ -83,7 +84,8 @@
       return
       end
 
-      subroutine errorrep(val)
+      subroutine errorrep(val) BIND(C)
+      use dballef
       integer val
       character buf*1000
 
