@@ -62,9 +62,11 @@ void trace_init()
 {
     // Init API tracing if requested
     const char* tracefile = getenv("DBALLE_TRACE_FORTRAN");
+    if (!tracefile) tracefile = getenv("DBA_FORTRAN_TRACE");
     if (tracefile)
     {
         trace_file = fopen(tracefile, "at");
+        setvbuf(trace_file, nullptr, _IOLBF, 0);
         do_trace = true;
         fprintf(trace_file, "// ** Execution begins **\n");
     }
